pub struct SaveSettings { /* private fields */ }Expand description
Settings to alter the behavior of creating snapshots saved within a Database.
Implementations
Sourceimpl SaveSettings
impl SaveSettings
pub fn new() -> Ref<Self>
Sourcepub fn with_option(&self, option: SaveOption) -> Ref<Self>
pub fn with_option(&self, option: SaveOption) -> Ref<Self>
Sets the specified option to true and returns a ref counted SaveSettings that can
continued to be chained.
pub fn set_option(&self, option: SaveOption, value: bool)
pub fn option(&self, option: SaveOption) -> bool
Sourcepub fn snapshot_name(&self) -> String
pub fn snapshot_name(&self) -> String
When saving an automatic snapshot via FileMetadata::save_auto_snapshot this name will be
used for the newly written snapshot.
pub fn set_snapshot_name(&self, name: &str)